Pydoop Documentation — Pydoop 0.12.0 documentation

### Navigation

- index
- modules |
- next |
- Home|
- Download & Install|
- Support|
- Pydoop on SF

# Pydoop Documentation

Welcome to the documentation for Pydoop 0.12.0. Pydoop is a package that provides a Python API for Hadoop. To get started, read the tutorial.

# Contents

- News
- Tutorial
- Installation
- Pydoop Script User Guide
- Running Pydoop Applications
- API Docs
- Examples
- Installation-free Usage
- Pydoop for Dumbo Users
- Ideas List

# How to Cite

Pydoop is developed and maintained by researchers at CRS4 – Distributed Computing group. If you use Pydoop as part of your research work, please cite the HPDC 2010 paper.

Plain text:

    S. Leo and G. Zanetti.  Pydoop: a Python MapReduce and HDFS API for
    Hadoop.  In Proceedings of the 19th ACM International Symposium on
    High Performance Distributed Computing, 819-825, 2010.

BibTeX:

    @inproceedings{Leo:2010:PPM:1851476.1851594,
     author = {Leo, Simone and Zanetti, Gianluigi},
     title = {{Pydoop: a Python MapReduce and HDFS API for Hadoop}},
     booktitle = {{Proceedings of the 19th ACM International Symposium on High Performance Distributed Computing}},
     series = {HPDC '10},
     year = {2010},
     isbn = {978-1-60558-942-8},
     location = {Chicago, Illinois},
     pages = {819--825},
     numpages = {7},
     url = {http://doi.acm.org/10.1145/1851476.1851594},
     doi = {10.1145/1851476.1851594},
     acmid = {1851594},
     publisher = {ACM},
     address = {New York, NY, USA},
    }

# Indices and Tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- Home|
- Download & Install|
- Support|
- Pydoop on SF